@@ -24,7 +24,7 @@ from calculate.lib.datavars import (TableVariable, Variable, ReadonlyVariable,
 from calculate.lib.utils.files import listDirectory, process, PIPE, pathJoin
 from calculate.lib.utils.portage import isPkgInstalled, RepositoryPath
 from calculate.lib.utils.common import cmpVersion
-from calculate.lib.datavars import DataVars, SimpleDataVars
+from calculate.lib.datavars import DataVars
 from itertools import dropwhile
 import re
 import contextlib
